@@ -10,10 +10,11 @@ extern crate mime_guess;
 extern crate itertools;
 extern crate tabwriter;
 extern crate lazysort;
-extern crate brotli2;
 extern crate unicase;
 extern crate walkdir;
 extern crate base64;
+extern crate blake3;
+extern crate brotli;
 extern crate flate2;
 extern crate rfsapi;
 #[cfg(target_os = "windows")]
@@ -30,7 +31,6 @@ extern crate iron;
 extern crate libc;
 extern crate rand;
 extern crate time;
-extern crate md6;
 extern crate xml;
 
 mod error;
